#
# spec file for package libircclient
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 1
Name:           libircclient
Version:        1.10
Release:        1.20
Summary:        Library implementing client-server IRC protocol
License:        LGPL-2.0-or-later
Group:          System/Libraries
URL:            http://libircclient.sourceforge.net/
Source0:        http://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE  libircclient-memory-overflow.diff
Patch0:         libircclient-memory-overflow.diff
# PATCH-FIX-UPSTREAM libircclient-cipher-suite.patch bnc#857151
Patch1:         libircclient-cipher-suite.diff
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1500
BuildRequires:  python3-Sphinx
BuildRequires:  python3-Sphinx-latex
%else
BuildRequires:  python-Sphinx
BuildRequires:  python-Sphinx-latex
%endif
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libssl)

%description
It is designed to be small, fast, portable and compatible to RFC standards and most IRC clients.

%package -n %{name}%{soname}
Summary:        Library implementing client-server IRC protocol
Group:          Development/Libraries/C and C++

%description -n %{name}%{soname}
It is designed to be small, fast, portable and compatible to RFC standards and most IRC clients.

%package -n %{name}-devel
Summary:        Header files and libraries for compiling against libircclient
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}

%description -n %{name}-devel
It is designed to be small, fast, portable and compatible to RFC standards and most IRC clients.

%package -n %{name}-doc
Summary:        Documentation for libircclient
Group:          Development/Libraries/C and C++

%description -n %{name}-doc
It is designed to be small, fast, portable and compatible to RFC standards and most IRC clients.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
%configure --enable-ipv6 --enable-openssl --enable-shared
make %{?_smp_mflags}
cd doc
make html

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p "%{buildroot}/%{_mandir}/man1";
install -pm0644 man/libircclient.1 "%{buildroot}/%{_mandir}/man1/";

%post -n %{name}%{soname} -p /sbin/ldconfig
%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%doc Changelog README THANKS
%license LICENSE
%{_libdir}/libircclient.so.%{soname}

%files -n %{name}-devel
%{_includedir}/*
%{_libdir}/libircclient.so
%{_mandir}/man1/*

%files -n %{name}-doc
%doc doc/_build/html examples/*.cpp examples/*.c

%changelog
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.10:
  * Fixed compatibility with OpenSSL 1.1.x (thanks Antoine Amarilli)
  * Fixed a few minor Win32 compatibility bugs.
  * Fixed an error if the TCP connection to the IRC server couldn't be established under 250ms.
  * Fixed a potential deadlock caused by WSAStartup() being called in DllMain()
- remove pdfgen.patch (upstream)
* Tue Aug 28 2018 adam.majer@suse.de
- pdfgen.patch: use sphinx with latex to build documentation as
  python-rst2pdf is only python2 at the moment
* Thu Dec 28 2017 crrodriguez@opensuse.org
- export ac_cv_lib_ssl_SSL_library_init=yes before configure
  to workaround buggy libssl check, in openSSL 1.1
  SSL_library_init is a compatibility macro and not a symbol
  in the shared library.
* Mon Jun 13 2016 joop.boonen@opensuse.org
- cipher suite fix from ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH to
  EECDH+AESGCM:EDH+AESGCM:AES256+EECDH:AES256+EDH
  bnc#857151 libircclient-cipher-suite.diff
* Mon Jun 13 2016 joop.boonen@opensuse.org
- Update to version 1.9
  * Fixed a few minor Win32 compatibility bugs.
  * Fixed an error if the TCP connection to the IRC server couldn't be established under 250ms.
  * Fixed a potential deadlock caused by WSAStartup() being called in DllMain()
* Tue Feb 10 2015 p.drouand@gmail.com
- Update to version 1.8
  * ChangeLog has not been updated for a while
- Use download Url as source
- Remove gcc dependency;
- Add python-rst2pdf and python-Sphinx require to build documentation
- Remove libircclient-make.diff; fixed on upstream release
* Wed Feb 15 2012 saschpe@suse.de
- Ran spec-cleaner
- Provide more detail about version update in last changelog entry
* Sun Feb 12 2012 joop.boonen@opensuse.org
- Update to version 1.6:
  * Fixed PRIVMSG events incorrectly reported as CHANNEL (thx Dennis Bretjes)
  * Added -fpic option for the shared library; fixed make install
  * WIN32 macro replaced by _WIN32 (Lothar May)
  * Fixed IPv6 and IPv4 connections being used simultaneously (Lothar May)
  * Fixed DCC file transfer with IPv6 build (Lothar May)
- Seperate doc package
- Make file corrections
* Sat Dec 24 2011 jengelh@medozas.de
- Summary update for shlib package; avoid macros in summaries
* Sat Dec 24 2011 joop.boonen@opensuse.org
- Added missing header files
* Fri Dec 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Replace libircclient-makefile.patch by libircclient-automake.diff
  and apply correct SO versioning
* Fri Dec 23 2011 joop.boonen@opensuse.org
- openSUSE build of libircclient based on Fedora package
* Mon May  2 2011 Adam Huffman <bloch@verdurin.com>
- better soname fix
* Fri Apr 29 2011 Adam Huffman <bloch@verdurin.com>
- fix soname
* Fri Apr 29 2011 Adam Huffman <bloch@verdurin.com>
- ignore provided makefiles
- devel subpackage
* Fri Apr 29 2011 Adam Huffman <bloch@verdurin.com>
- remove static library
* Sat Feb 12 2011 Adam Huffman <bloch@verdurin.com>
- fixes taken from Arch package to help with din
- build .so
* Wed Jun  2 2010 Conrad Meyer <konrad@tylerc.org>
- First attempt at a package (crappy)
